@@ -1,12 +1,25 @@
 import jsonlines
 
 import attr
+import logbook
 from tqdm import tqdm
 
+from regipy import NKRecord
 from regipy.plugins.plugin import PLUGINS
 
 
-def dump_hive_to_json(registry_hive, output_path, name_key_entry, verbose=False):
+logger = logbook.Logger(__name__)
+
+
+def dump_hive_to_json(registry_hive, output_path, name_key_entry: NKRecord, verbose=False):
+    """
+    Write the hive subkeys to a JSON file
+    :param registry_hive: a RegistryHive object
+    :param output_path: Output path to save the JSON
+    :param name_key_entry: The NKRecord to start iterating from
+    :param verbose: verbosity
+    :return: The result, as dict
+    """
     with jsonlines.open(output_path, mode='w') as writer:
         for entry in tqdm(registry_hive.recurse_subkeys(name_key_entry, as_json=True), disable=not verbose):
             writer.write(attr.asdict(entry))
